==> context-2.1.1-alpha1-sources.jar: com/flybits/context/plugins/location/LocationContextPluginService.java <==
package com.flybits.context.plugins.location;

import android.Manifest;
import android.content.pm.PackageManager;
import android.location.Location;
import android.os.Build;
import android.os.Bundle;
import androidx.core.content.ContextCompat;

import com.flybits.commons.library.logging.Logger;
import com.flybits.context.models.ContextData;
import com.flybits.context.services.FlybitsContextPluginService;
import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.tasks.Tasks;

import java.util.concurrent.ExecutionException;

/**
 * The {@link LocationContextPluginService} is a service responsible for retrieving the last location.
 * The minimum interval for the service to execute is specified by refresh time.
 * Permissions required are : ACCESS_FINE_LOCATION and ACCESS_COARSE_LOCATION.
 */
public class LocationContextPluginService extends FlybitsContextPluginService {
    private final static String TAG_LOCATION_PLUGIN = "PluginLocation";
    private FusedLocationProviderClient fusedLocationProviderClient;
    private long minDisplacement = -1;

    @Override
    public void initialize(Bundle bundle) {
        fusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(getApplicationContext());
        if (bundle != null && bundle.containsKey("minDisplacement")) {
            minDisplacement = bundle.getLong("minDisplacement");
        }
    }

    @Override
    public boolean isSupported() {
        return Build.VERSION.SDK_INT < 23 ||
                ContextCompat.checkSelfPermission(getBaseContext(), Manifest.permission.ACCESS_FINE_LOCATION) == PackageManager.PERMISSION_GRANTED;
    }

    @Override
    public ContextData getData() {
        Logger.appendTag(TAG_LOCATION_PLUGIN).d("Fetching Data ...");
        try {
            // Using Tasks.await to get the result synchronously without callback.
            if (isSupported()) {
                Location lastLocation = Tasks.await(fusedLocationProviderClient.getLastLocation());
                return new LocationData(lastLocation);
            } else {
                return null;
            }
        } catch (ExecutionException | InterruptedException e) {
            Logger.appendTag(TAG_LOCATION_PLUGIN).e("Exception : " + e.getMessage());
        }
        return null;
    }


    @Override
    public void onDestroy() {
        Logger.appendTag(TAG_LOCATION_PLUGIN).d("...Destroyed");
        super.onDestroy();
    }

    @Override
    public String[] getRequiredPermissions() {
        return new String[]{Manifest.permission.ACCESS_FINE_LOCATION, Manifest.permission.ACCESS_COARSE_LOCATION};
    }
}

==> context-2.3.5-alpha1-sources.jar: com/flybits/context/plugins/location/LocationContextPluginService.java <==
package com.flybits.context.plugins.location;

import android.Manifest;
import android.content.pm.PackageManager;
import android.location.Location;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.content.ContextCompat;

import com.flybits.commons.library.logging.Logger;
import com.flybits.context.models.ContextData;
import com.flybits.context.services.FlybitsContextPluginService;
import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.location.LocationServices;
import com.google.android.gms.tasks.Tasks;

import java.util.concurrent.ExecutionException;

/**
 * The {@link LocationContextPluginService} is a service responsible for retrieving the last location.
 * The minimum interval for the service to execute is specified by refresh time.
 * Permissions required are : ACCESS_FINE_LOCATION and ACCESS_COARSE_LOCATION.
 *
 * @deprecated in version 2.3.0, will be removed in version 4.0.0.
 * Alternate {@link LocationContextPluginWorker} using WorkerManager API can be used.
 * This functionality will be removed from the SDK.
 *
 */
public class LocationContextPluginService extends FlybitsContextPluginService {
    private final static String TAG_LOCATION_PLUGIN = "PluginLocation";
    private FusedLocationProviderClient fusedLocationProviderClient;
    private long minDisplacement = -1;

    @Override
    public void initialize(Bundle bundle) {
        fusedLocationProviderClient = LocationServices.getFusedLocationProviderClient(getApplicationContext());
        if (bundle != null && bundle.containsKey("minDisplacement")) {
            minDisplacement = bundle.getLong("minDisplacement");
        }
    }

    @Override
    public boolean isSupported() {
        return Build.VERSION.SDK_INT < 23 ||
                ContextCompat.checkSelfPermission(getBaseContext(), Manifest.permission.ACCESS_FINE_LOCATION) == PackageManager.PERMISSION_GRANTED;
    }

    @Override
    public ContextData getData() {
        Logger.appendTag(TAG_LOCATION_PLUGIN).d("Fetching Data ...");
        try {
            // Using Tasks.await to get the result synchronously without callback.
            if (isSupported()) {
                Location lastLocation = Tasks.await(fusedLocationProviderClient.getLastLocation());
                return new LocationData(lastLocation);
            } else {
                return null;
            }
        } catch (ExecutionException | InterruptedException e) {
            Logger.appendTag(TAG_LOCATION_PLUGIN).e("Exception : " + e.getMessage());
        }
        return null;
    }


    @Override
    public void onDestroy() {
        Logger.appendTag(TAG_LOCATION_PLUGIN).d("...Destroyed");
        super.onDestroy();
    }

    @Override
    public String[] getRequiredPermissions() {
        return new String[]{Manifest.permission.ACCESS_FINE_LOCATION, Manifest.permission.ACCESS_COARSE_LOCATION};
    }
}
